#
# spec file for package qore
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2014 David Nichols <david@qore.org>
# Copyright (c) 2014 Petr Vanek <petr@yarpen.cz>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define module_dir %{_libdir}/qore-modules
Name:           qore
Version:        0.8.13
Release:        bp153.1.28
Summary:        Multithreaded Programming Language
License:        LGPL-2.1-or-later OR GPL-2.0-or-later OR MIT
Group:          Development/Languages/Other
Url:            http://qore.org
Source:         https://github.com/qorelanguage/qore/releases/download/release-%{version}/qore-%{version}.tar.bz2
Source99:       qore-module.prov
Patch:          qore-libtool-2.4.6.patch
# PATCH-FIX-OPENSUSE bmwiedemann boo#1084909
Patch1:         reproducible.patch
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  bzip2
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  flex >= 2.5.31
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel
BuildRequires:  libbz2-devel
BuildRequires:  libtool
BuildRequires:  mpfr-devel
BuildRequires:  openssl-devel
BuildRequires:  pcre-devel
BuildRequires:  pkg-config
BuildRequires:  zlib-devel
Requires:       %{_bindir}/env
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Qore is a scripting language supporting threading and embedded logic, designed
for applying a flexible scripting-based approach to enterprise interface
development but is also useful as a general purpose language.

%package -n libqore5
Summary:        The libraries for the qore runtime and qore clients
License:        LGPL-2.0-or-later OR GPL-2.0-or-later OR MIT
Group:          Development/Languages/Other
Provides:       qore-module(abi)%{?_isa} = 0.18
Provides:       qore-module(abi)%{?_isa} = 0.19
Provides:       qore-module(abi)%{?_isa} = 0.20
# provided for backwards-compatibility with unversioned capabilities and will be removed when the ABI drops backwards-compatibility
%(cat %{SOURCE99})

%description -n libqore5
Qore is a scripting language supporting threading and embedded logic, designed
for applying a flexible scripting-based approach to enterprise interface
development but is also useful as a general purpose language.

This package provides the qore library required for all clients using qore
functionality.

%files -n libqore5
%defattr(-,root,root,-)
%{_libdir}/libqore.so.5.14.0
%{_libdir}/libqore.so.5
%doc COPYING.LGPL COPYING.GPL COPYING.MIT README-LICENSE

%post -n libqore5 -p /sbin/ldconfig
%postun -n libqore5 -p /sbin/ldconfig

%package doc
Summary:        API documentation, programming language reference, and Qore example programs
License:        LGPL-2.0-or-later OR GPL-2.0-or-later OR MIT
Group:          Documentation/HTML

%description doc
Qore is a scripting language supporting threading and embedded logic, designed
for applying a flexible scripting-based approach to enterprise interface
development but is also useful as a general purpose language.

This package provides the HTML documentation for the Qore programming language
and also for user modules delivered with Qore and also example programs.

%files doc
%defattr(-,root,root,-)
%doc docs/lang docs/modules/* examples/ README.md README-MODULES RELEASE-NOTES AUTHORS ABOUT

%package devel
Summary:        The header files needed to compile programs using the qore library
License:        LGPL-2.0-or-later OR GPL-2.0-or-later OR MIT
Group:          Development/Languages/C and C++
Requires:       libqore5 = %{version}-%{release}

%description devel
Qore is a scripting language supporting threading and embedded logic, designed
for applying a flexible scripting-based approach to enterprise interface
development but is also useful as a general purpose language.

This package provides header files needed to compile client programs using the
Qore library.

%files devel
%defattr(-,root,root,-)
%{_bindir}/qpp
%{_bindir}/qdx
%{_libdir}/libqore.so
%{_libdir}/pkgconfig/qore.pc
%dir %{_libdir}/cmake
%{_libdir}/cmake/Qore
%{_includedir}/*
%{_datadir}/qore

%package devel-doc
Summary:        C++ API documentation for the qore library
License:        LGPL-2.0-or-later OR GPL-2.0-or-later OR MIT
Group:          Documentation/HTML
Requires:       libqore5 = %{version}-%{release}

%description devel-doc
Qore is a scripting language supporting threading and embedded logic, designed
for applying a flexible scripting-based approach to enterprise interface
development but is also useful as a general purpose language.

%files devel-doc
%defattr(-,root,root,-)
%doc docs/library/html/*

%package misc-tools
Summary:        Miscellaneous user tools writen in Qore Programming Language
License:        LGPL-2.0-or-later OR GPL-2.0-or-later OR MIT
Group:          Development/Tools/Other
Requires:       qore = %{version}-%{release}

%description misc-tools
This package contains tool for working with:
 - REST APIs
 - SQL Databases

%files misc-tools
%defattr(-,root,root,-)
%{_bindir}/qget
%{_bindir}/rest
%{_bindir}/sfrest
%{_bindir}/sqlutil
%{_bindir}/schema-reverse

%prep
%setup -q
%patch -p1
%patch1 -p1
# silence the executable warning for examples
find examples -type f|xargs chmod 644

%build
aclocal
autoreconf -fi
%if "%_lib" == "lib64"
c64=--enable-64bit
%endif
%configure --disable-debug --disable-static $c64
make %{?_smp_mflags}

%install
mkdir -p %{buildroot}%{_prefix}/bin
mkdir -p %{buildroot}/%{module_dir}/%{version}
mkdir -p %{buildroot}%{_prefix}/man/man1
make install prefix=%{_prefix} DESTDIR=%{buildroot}
rm %{buildroot}/%{_libdir}/libqore.la
%fdupes -s docs

# Check if we have all the provides for libqore - to ensure we provide all the qore-module-api-* the code supports
./qore --module-apis | awk -F',[[:blank:]]' '{i = 1; while (i < NF) { print "Provides: qore-module-api-"$i; i++  } }' > /tmp/qore-modules.prov
diff -ur %{SOURCE99} /tmp/qore-modules.prov

%files
%defattr(-,root,root,-)
%{_bindir}/qore
%{_bindir}/qdbg*
%{module_dir}
%dir %{_datadir}/qore-modules
%{_datadir}/qore-modules/0.8.13
%{_mandir}/man1/qore.1.*

%changelog
* Mon Aug  5 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Make the qore-module-api-* provides more fail prove: store the
  provides list in qore-module.prov. During build, this file is
  auto-generated and compared against the package provided one to
  ensure the list is correct.
* Thu Jul 12 2018 bwiedemann@suse.com
- Add reproducible.patch to not include build hostname in package
  to make build reproducible (boo#1084909)
* Thu Oct 12 2017 jengelh@inai.de
- Rework scriptlets for ldconfig. Adjust RPM groups.
  Avoid double-shipping of files. Use %%configure.
* Fri Sep 29 2017 petr@yarpen.cz
- updated to 0.8.13
- Input/Output stream APIs
- Vastly improved type system with complex type support
  Improved operators; list, string, binary slice operators,
  the ".." range operator, improved new, cast<>, and
  instanceof operators, lazy evaluation of functional and
  list operators, more
- Improved encryption support including AES encryption,
  encryption/decryption streams, support for AAD and MACs
  Improved HTTPS and SSL security support with addition
  X.509 certificate support including automatic certificate
  verification in client and server contexts
- Universal connection API
- Support for binding output placeholder buffers for result
  sets that return an SQLStatement object for more efficient
  piecewise processing of DB stored procedure/function calls
  that return very large result sets
- Strong encapsulation support (ex: private:internal)
- Deterministic garbage collection performance improvements
  with large cycles
- Debugging support and APIs including remote network debugging
- Language Server Protocol support for Qore in the new astparser
  module for rich language support in IDEs such as the Visual
  studio Code Qore Extension
- much more
- rpm: /usr/bin user programs are part of qore-misc-tools package
  now as it was suggested by advanced packagers on IRC
- rpm: updated qore-libtool-2.4.6.patch for new release
* Thu Sep  8 2016 petr@yarpen.cz
- updated to 0.8.12.1
- removed un-applicable patches: configure.patch
* Fri Jun 12 2015 dimstar@opensuse.org
- Add qore-libtool-2.4.6.patch: Remove imported Libtool 2.4.2
  macros from acinclude.m4: this is a terrible hack by upstream to
  not forcibly depend on libtool >= 2.4.2, which has a very bad
  side effect now with libtool 2.4.6 available: the macros conflict
  due the internal API changes inside libtool.
* Sun Jul 13 2014 schwab@linux-m68k.org
- configure.patch: don't use -m32/-m64
* Fri Jun 20 2014 petr@yarpen.cz
- updated to 0.8.11
* Fri Dec 14 2012 petr@yarpen.cz
- spec file reformatted to fit OBS rules
* Thu Nov  8 2012 david@qore.org
- updated to 0.8.6.2
* Fri Oct 26 2012 david@qore.org
- updated to 0.8.6.1
* Sat Sep  1 2012 david@qore.org
- updated to 0.8.6
* Tue May 22 2012 david@qore.org
- updated to 0.8.5
* Mon May 21 2012 david@qore.org
- updated for new doxygen-based documentation, added devel-doc pkg
  for API docs
- updated package descriptions
* Wed Oct 19 2011 david@qore.org
- updated to 0.8.4
* Thu Oct  6 2011 petr.vanek@qoretechnologies.com
- pkg-config
* Sat Mar  5 2011 david@qore.org
- updated to 0.8.3
* Sat Dec 25 2010 david@qore.org
- updated to 0.8.2
* Mon Jun 14 2010 david@qore.org
- updated to 0.8.1
* Tue Nov 17 2009 david_nichols@users.sourceforge.net
- updated to 0.8.0
* Thu Nov  5 2009 david_nichols@users.sourceforge.net
- updated to 0.7.7
* Sun Jul 12 2009 david_nichols@users.sourceforge.net
- updated to 0.7.6
* Sun Jun 21 2009 david_nichols@users.sourceforge.net
- updated to 0.7.5
* Tue Mar  3 2009 david_nichols@users.sourceforge.net
- updated to 0.7.4
* Tue Dec  2 2008 david_nichols@users.sourceforge.net
- updated to 0.7.3
* Tue Nov 25 2008 david_nichols@users.sourceforge.net
- made libqore* the default name for lib package, removed la file
* Sat Nov 22 2008 david_nichols@users.sourceforge.net
- updated to 0.7.2
* Sun Oct 12 2008 david_nichols@users.sourceforge.net
- fixed devel pacakges for suse
* Mon Oct  6 2008 david_nichols@users.sourceforge.net
- released 0.7.0
* Wed Sep  3 2008 david_nichols@users.sourceforge.net
- removed all modules as they are now independent projects
* Mon Sep  1 2008 david_nichols@users.sourceforge.net
- fixed dist tag for suse distributions
- updated for new module directory, added qore-module-api-*
  capability
* Sun Jul 13 2008 david_nichols@users.sourceforge.net
- copied improvements from opensuse rpm and updated based
  on rpmlint output
- updated version to 0.7.0
* Fri Jun 13 2008 david_nichols@users.sourceforge.net
- fixed spec file to support more architectures
* Thu Apr 10 2008 david_nichols@users.sourceforge.net
- updated package to 0.6.2.4 and disabled mssql module build due
- to lack of freetds packages in the build service :-(
* Sun Oct 15 2006 mrueckert@suse.de
- added --enable-64bit to build properly on 64bit biarch
* Sun Oct 15 2006 mrueckert@suse.de
- initial package of 0.5.3
